==============================
Salt 2015.8.0rc3 Release Notes
==============================

Extended changelog courtesy of Todd Stansell (https://github.com/tjstansell/salt-changelogs):

*Generated at: 2015-08-04T17:21:50Z*

Statistics:

- Total Merges: **122**
- Total Issue references: **69**
- Total PR references: **153**

Changes:


- **PR** `#26001`_: (*cachedout*) Fix failing tests
  @ *2015-08-04T15:48:47Z*

  - **PR** `#25978`_: (*anlutro*) Correct service state changes in test mode
    | refs: `#26001`_
  * 4e50c81 Merge pull request `#26001`_ from cachedout/fix_tests_25978
  * 85f5e2a Fix failing tests

- **PR** `#25978`_: (*anlutro*) Correct service state changes in test mode
  | refs: `#26001`_
  @ *2015-08-04T15:45:26Z*

  * 584d608 Merge pull request `#25978`_ from alprs/fix-service_test_changes
  * 1bc981b service state: correct result in test mode

- **PR** `#25982`_: (*sjorge*) salt.modules.smartos_* limit to global zone only
  @ *2015-08-04T14:43:54Z*

  * 8bc9c51 Merge pull request `#25982`_ from sjorge/smartos-modules-tweaks
  * d39bdbd salt.modules.smartos_* limit to global zone only

- **PR** `#25989`_: (*rallytime*) Back-port `#25832`_ to 2015.8
  @ *2015-08-04T14:37:41Z*

  - **ISSUE** `#25557`_: (*DmitryKuzmenko*) salt-master MWorker high memory usage on big job output
    | refs: `#25832`_
  - **PR** `#25832`_: (*DmitryKuzmenko*) Event subscribe fix
    | refs: `#25989`_
  * e2e1d3f Merge pull request `#25989`_ from rallytime/`bp-25832`_
  * cfbfb34 Update RaetEvent to conform to the SaltEvent interface.

  * 5c6276a Subscribe event to bus is optional now

- **PR** `#25988`_: (*cachedout*) Move `#25642`_ to 2015.8
  @ *2015-08-04T14:37:03Z*

  - **ISSUE** `#25899`_: (*basepi*) Re-fix `#25642`_ in 2015.8
    | refs: `#25988`_
  - **ISSUE** `#25540`_: (*dennisjac*) salt highstate schedule cannot be removed
    | refs: `#25642`_
  - **PR** `#25642`_: (*cachedout*) Warn on pillar schedule delete
  * 0450cad Merge pull request `#25988`_ from cachedout/issue_25899
  * 299875d Move `#25642`_ to 2015.8

- **PR** `#25999`_: (*s0undt3ch*) Include subschema defaults
  @ *2015-08-04T13:04:08Z*

  * d98cd97 Merge pull request `#25999`_ from s0undt3ch/2015.8
  * 3d73110 Include subschema defaults

- **PR** `#25997`_: (*s0undt3ch*) Allow getting a defaults dictionary from schema defaults
  @ *2015-08-04T12:18:00Z*

  * 5a892aa Merge pull request `#25997`_ from s0undt3ch/2015.8
  * d576e00 Allow getting a defaults dictionary from schema defaults

- **PR** `#25979`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-08-03T23:15:52Z*

  - **ISSUE** `#25863`_: (*peterdemin*) pkg.installed fails on already installed package if it is in versionlock.list
    | refs: `#25864`_
  - **ISSUE** `#25852`_: (*UtahDave*) Salt loader is not loading Salt vars in reactor python renderer
    | refs: `#25927`_
  - **ISSUE** `#25850`_: (*ssgward*) Need to add packages to --versions-report
    | refs: `#25941`_
  - **ISSUE** `#25839`_: (*twangboy*) ALLUSERS="1" should be a default when installing MSI's
    | refs: `#25848`_
  - **ISSUE** `#25838`_: (*grep4linux*) docs disable_modules documentation typo
    | refs: `#25942`_
  - **ISSUE** `#25810`_: (*nvx*) winpkg highstate fails when a new package name contains a unicide character
    | refs: `#25921`_
  - **ISSUE** `#25650`_: (*jacksontj*) state.running documentation is incorrect
    | refs: `#25894`_
  - **ISSUE** `#25577`_: (*yellow1912*) Wrong indentation in document
    | refs: `#25696`_
  - **ISSUE** `#24042`_: (*whiteinge*) The state_events setting is not documented
    | refs: `#25894`_
  - **ISSUE** `#24036`_: (*arthurlogilab*) [salt-cloud] Protect against passing command line arguments as names for the --destroy command in map files
    | refs: `#25877`_
  - **ISSUE** `#23788`_: (*k5jj*) functions in drac.py module do not match documentation
    | refs: `#25894`_
  - **ISSUE** `#23764`_: (*es1o*) source_hash from local file is not supported.
    | refs: `#25750`_
  - **ISSUE** `#21296`_: (*Lothiraldan*) Possible minion enumeration using saltutil.find_job and eauth
    | refs: `#25894`_
  - **PR** `#25967`_: (*rallytime*) Back-port `#25917`_ to 2015.5
  - **PR** `#25966`_: (*rallytime*) Back-port `#25864`_ to 2015.5
  - **PR** `#25951`_: (*garethgreenaway*) Log when event.fire and event.fire_master fail.
  - **PR** `#25942`_: (*jfindlay*) typo in minion doc
  - **PR** `#25941`_: (*jfindlay*) add timelib to dependency versions
  - **PR** `#25938`_: (*jacobhammons*) Doc on using syndic with multimaster
  - **PR** `#25927`_: (*jacksontj*) Pass actual renderers to the Reactor's Compiler
  - **PR** `#25921`_: (*cachedout*) Handle non-ascii in state log
  - **PR** `#25919`_: (*TheBigBear*) Minor update to msi un-installer info
  - **PR** `#25917`_: (*jmdcal*) adding missing format string
    | refs: `#25967`_
  - **PR** `#25905`_: (*rallytime*) Back-port `#25982`_ to 2015.5
  - **PR** `#25898`_: (*jfindlay*) clarify and expand syndic docs
  - **PR** `#25895`_: (*basepi*) [2015.5] Merge forward from 2014.7 to 2015.5
  - **PR** `#25894`_: (*jacobhammons*) Minor doc bug fixes
  - **PR** `#25892`_: (*TheBigBear*) Update 7-zip msi un-installer instructions
    | refs: `#25905`_ `#25907`_
  - **PR** `#25890`_: (*rallytime*) Back-port `#25698`_ to 2015.5
  - **PR** `#25877`_: (*rallytime*) Protect against passing a map file in addition to VM names with --destroy
  - **PR** `#25870`_: (*rallytime*) Back-port `#25824`_ to 2015.5
  - **PR** `#25864`_: (*peterdemin*) `#25863`_ state.pkg.installed fix
    | refs: `#25966`_
  - **PR** `#25848`_: (*twangboy*) Added allusers="1" when installing msi
  - **PR** `#25824`_: (*klyr*) Fix get_managed() in file.py module for local files
    | refs: `#25870`_
  - **PR** `#25750`_: (*alekti*) Add file as supported protocol for file source_hash. Fixes `#25701`_.
  - **PR** `#25704`_: (*cachedout*) Ensure prior alignment with master_type in 2014.7
  - **PR** `#25698`_: (*rallytime*) Back-port `#25659`_ to 2015.8
    | refs: `#25890`_
  - **PR** `#25696`_: (*AkhterAli*) Update schedule.py
  - **PR** `#25659`_: (*isbm*) Bugfix: crash at getting non-existing repo
    | refs: `#25698`_
  - **PR** `#25657`_: (*MrCitron*) Add the ability to specify a base pattern for carbon returner
  - **PR** `#25633`_: (*AkhterAli*) Update loader.py
  - **PR** `#14690`_: (*jacksontj*) Multi syndic
    | refs: `#25938`_
  * 2e79213 Merge pull request `#25979`_ from basepi/merge-forward-2015.8
  * f4cb659 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

  * 2dca8d9 Merge pull request `#25966`_ from rallytime/`bp-25864`_

    * 0f7f963 `#25863`_ fix - state.pkg: do preflight check only for non-installed packages

  * a6d8e54 Merge pull request `#25967`_ from rallytime/`bp-25917`_

    * 82b7e14 adding missing format string

  * 87d028b Merge pull request `#25895`_ from basepi/merge-forward-2015.5

    * 56e43c8 Fix lint

    * 93a182d Merge remote-tracking branch 'upstream/2014.7' into merge-forward-2015.5

      * d93eb87 Merge pull request `#25750`_ from alekti/2014.7

        * 9ec3ae9 Add file as supported protocol for file source_hash. Fixes `#23764`_.

      * 3a15df2 Merge pull request `#25704`_ from cachedout/master_type_2014_7

        * c95886c Ensure prior alignment with master_type in 2014.7

      * d1b9362 Merge pull request `#25657`_ from MrCitron/pattern-carbon-returner-2014.7

        * f8b2f80 Add the ability to specify a base pattern for metrics path used by the carbon returner

      * 9634351 Merge pull request `#25633`_ from AkhterAli/2014.7

      * 29be4bb Update loader.py

  * 9895505 Merge pull request `#25941`_ from jfindlay/time_lib

    * 464f7a4 add timelib to dependency versions

  * dcc6883 Merge pull request `#25951`_ from garethgreenaway/event_fire_failed_log_why

    * 7f20454 If we're unable to fire an event, log the cause so we know what happened

  * 4143cec Merge pull request `#25942`_ from saltstack/lover

    * 7e121de Update minion.rst

  * 1f20c06 Merge pull request `#25938`_ from jacobhammons/syndic-multimaster

    * ac0a8ff Doc on using syndic with multimaster

  * 18a9e65 Merge pull request `#25848`_ from twangboy/fix_25839

    * e797739 Removed normalize_name function

    * ad7fdda Adder allusers="1" when installing msi

  * de0a059 Merge pull request `#25898`_ from jfindlay/syndic_doc

    * 4795952 rework syndic doc

    * a25d0ea update syndic doc to conform to style

  * d1f3da5 Merge pull request `#25927`_ from jacksontj/2015.5

    * cf7479a Pass actual renderers to the Reactor's Compiler

  * 331fc12 Merge pull request `#25921`_ from cachedout/issue_25810

    * 8074c54 Handle non-ascii in state log

  * 20fb8da Merge pull request `#25919`_ from TheBigBear/patch-4

    * c994d22 Minor update to msi un-installer info

  * 9a569da Merge pull request `#25905`_ from rallytime/`bp-25892`_

    * 333fbdd Update 7-zip msi un-installer instructions

  * 6a738c5 Merge pull request `#25890`_ from rallytime/`bp-25696`_

    * 7d68e49 Update schedule.py

  * 8abb21e Merge pull request `#25894`_ from jacobhammons/bug-fixes

    * 3f3db4b Additions for `#24042`_

    * db2129b Minor doc bug fixes Refs `#24042`_ Refs `#25650`_ Refs `#21296`_ Refs `#23788`_

  * 59e1680 Merge pull request `#25877`_ from rallytime/`fix-24036`_

    * 0211972 Whitespace fix

    * c6715e0 Protect against passing a map file in addition to VM names with --destroy

    * 3aa5045 Clean up stacktrace when referenced map file doesn't exist

  * c4c9e40 Merge pull request `#25870`_ from rallytime/`bp-25824`_

    * 1fd4837 Fix get_managed() in file.py module for local files

- **PR** `#25902`_: (*basepi*) [2015.8] Merge forward from 2015.5 to 2015.8
  @ *2015-08-03T20:30:07Z*

  - **ISSUE** `#25827`_: (*0xf10e*) "Deprecating Code" doesn't mention Usage of warn_until() w/ Release Names
    | refs: `#25846`_
  - **ISSUE** `#25801`_: (*themalkolm*) Update docs that salt.states.winrepo requires `roles:salt-master` in grains.
    | refs: `#25840`_
  - **ISSUE** `#25717`_: (*twangboy*) Problem with chocolatey module not loading
    | refs: `#25755`_
  - **ISSUE** `#25689`_: (*anlutro*) Minion log in salt-ssh
    | refs: `#25694`_
  - **ISSUE** `#25674`_: (*UtahDave*) file.managed with contents parameter uses wrong line endings on Windows
    | refs: `#25675`_
  - **ISSUE** `#25665`_: (*nmadhok*) salt-cloud VMware driver fails with KeyErrors if there's any existing machine in the VMware infrastructure in (invalid state)
    | refs: `#25666`_
  - **ISSUE** `#25540`_: (*dennisjac*) salt highstate schedule cannot be removed
    | refs: `#25642`_
  - **ISSUE** `#25478`_: (*zyio*) salt-ssh - Unable to locate current thin version
    | refs: `#25862`_
  - **ISSUE** `#25447`_: (*spo0nman*) SaltMaster is crippled with Minion Re-Authentication
    | refs: `#25856`_
  - **ISSUE** `#25437`_: (*lorengordon*) Stacktrace on Windows when running pkg.list_pkgs
    | refs: `#25763`_
  - **ISSUE** `#25435`_: (*yee379*) progressbar dependency missing
    | refs: `#25714`_
  - **ISSUE** `#25413`_: (*zizkebab*) pillar_opts default behavior is not reflected in the docs
    | refs: `#25644`_
  - **ISSUE** `#25352`_: (*m03*) reg.absent reporting incorrect results
    | refs: `#25648`_
  - **ISSUE** `#25351`_: (*m03*) win_servermanager.list_installed failing with "IndexError: list index out of range"
    | refs: `#25711`_
  - **ISSUE** `#25258`_: (*nickw8*) windows minion repo not updating
    | refs: `#25798`_
  - **ISSUE** `#25250`_: (*wipfs*) 'force' option in copy state deletes target file
    | refs: `#25710`_
  - **ISSUE** `#25229`_: (*rall0r*) Module git.latest kills target directory when test=True
    | refs: `#25608`_
  - **ISSUE** `#25154`_: (*uvsmtid*) All data mixed on STDOUT together should generate valid JSON output
    | refs: `#25722`_
  - **ISSUE** `#25153`_: (*uvsmtid*) Multiple results should generate valid JSON output
    | refs: `#25722`_
  - **ISSUE** `#25144`_: (*johnccfm*) user.present on Windows fails to add user to groups if group name contains a space
    | refs: `#25702`_
  - **ISSUE** `#25026`_: (*sylvia-wang*) salt-ssh "Failure deploying thin" when using salt module functions
    | refs: `#25862`_
  - **ISSUE** `#24920`_: (*voileux*) module.zpool.create on character device is not possible by salt
    | refs: `#25749`_
  - **ISSUE** `#24002`_: (*csakoda*) File lock contention on windows minions causing highstate crash
    | refs: `#25788`_
  - **ISSUE** `#23288`_: (*UtahDave*) cp.push fails to recreate empty files.
    | refs: `#25833`_
  - **ISSUE** `#22699`_: (*arthurlogilab*) salt-cloud fails on KeyError when given a nonexistant action
    | refs: `#25807`_
  - **ISSUE** `#22460`_: (*onmeac*) Command setm is not supported (yet)
    | refs: `#25705`_
  - **ISSUE** `#19532`_: (*stolendog*) salt-ssh running git clone with not root user
    | refs: `#25853`_
  - **ISSUE** `#15209`_: (*hubez*) file.manage: source_hash not working with s3:// (2014.7.0rc1)
    | refs: `#25638`_
  - **ISSUE** `#11474`_: (*JensRantil*) pkgrepo.managed key_url: salt:// always use `base` env
    | refs: `#25831`_
  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
  - **PR** `#25885`_: (*t0rrant*) Update Debian changelog
  - **PR** `#25875`_: (*rallytime*) Back-port `#25862`_ to 2015.5
  - **PR** `#25873`_: (*rallytime*) Back-port `#25855`_ to 2015.5
  - **PR** `#25871`_: (*rallytime*) Back-port `#25829`_ to 2015.5
  - **PR** `#25869`_: (*rallytime*) Back-port `#25788`_ to 2015.5
  - **PR** `#25862`_: (*zyio*) Adding SCP_NOT_FOUND exit code
    | refs: `#25875`_
  - **PR** `#25856`_: (*jfindlay*) expand minion reauth scalability documentation
  - **PR** `#25855`_: (*puneetk*) Patch 3
    | refs: `#25873`_
  - **PR** `#25853`_: (*davidjb*) Make ssh-id-wrapper accessible to non-root users
  - **PR** `#25846`_: (*jfindlay*) rework deprecation documentation for release names
  - **PR** `#25840`_: (*jfindlay*) add note to winrepo state docs about required grain
  - **PR** `#25833`_: (*jahamn*) Allows cp.push to recreate empty files
  - **PR** `#25831`_: (*rallytime*) Add salt:// to key_url options to docs for pkgrepo.managed
  - **PR** `#25829`_: (*peterdemin*) Fixed typo in salt.states.saltmod.function doc string
    | refs: `#25871`_
  - **PR** `#25826`_: (*anlutro*) Check that "onchanges" is a list
  - **PR** `#25818`_: (*jfindlay*) fix autoruns list
  - **PR** `#25807`_: (*rallytime*) Provide helpful error when using actions with a mapfile
  - **PR** `#25798`_: (*twangboy*) Fixed stacktrace on package name not found
  - **PR** `#25797`_: (*twangboy*) Changed repocache back to cached_repo
  - **PR** `#25796`_: (*cachedout*) Remove debug from docs
  - **PR** `#25793`_: (*rallytime*) Back-port `#25730`_ to 2015.5
  - **PR** `#25792`_: (*rallytime*) Back-port `#25688`_ to 2015.5
  - **PR** `#25788`_: (*opdude*) Catch a hard crash when running highstate on windows
    | refs: `#25869`_
  - **PR** `#25763`_: (*twangboy*) Fix 25437
    | refs: `#25797`_
  - **PR** `#25755`_: (*twangboy*) Fixed problem with dunder functions not being passed
  - **PR** `#25752`_: (*thatch45*) State top saltenv
  - **PR** `#25749`_: (*jahamn*) Allow zpool.create on character devices
  - **PR** `#25740`_: (*rallytime*) Back-port `#25722`_ to 2015.5
  - **PR** `#25739`_: (*rallytime*) Back-port `#25709`_ to 2015.5
  - **PR** `#25738`_: (*rallytime*) Back-port `#25671`_ to 2015.5
  - **PR** `#25737`_: (*rallytime*) Back-port `#25608`_ to 2015.5
  - **PR** `#25733`_: (*davidjb*) Avoid IndexError when listing mounts if mount output ends in newline
  - **PR** `#25730`_: (*sjorge*) patchelf lives in pkgsrc
    | refs: `#25793`_
  - **PR** `#25722`_: (*uvsmtid*) Minor docs changes to emphasize JSON output problems without `--static` option
    | refs: `#25740`_
  - **PR** `#25714`_: (*cachedout*) Display warning when progressbar can't be loaded
  - **PR** `#25711`_: (*twangboy*) Fixed problem with win_servermanager.list_installed
  - **PR** `#25710`_: (*jahamn*) Integration Testcase for Issue 25250
  - **PR** `#25709`_: (*colekowalski*) add direct-io-mode to mount_invisible_options
    | refs: `#25739`_
  - **PR** `#25705`_: (*blackduckx*) Support for setm augeas command.
  - **PR** `#25703`_: (*cachedout*) Return to `str` for master_type for 2015.5
  - **PR** `#25702`_: (*twangboy*) Fixed win_user module for groups with spaces in the name
  - **PR** `#25699`_: (*rallytime*) Back-port `#25660`_ to 2015.5
    | refs: `#25709`_
  - **PR** `#25695`_: (*stanislavb*) Configurable AWS region & region from IAM metadata
  - **PR** `#25694`_: (*s0undt3ch*) Salt-SSH fix for `#25689`_
  - **PR** `#25688`_: (*bclermont*) Don't acquire lock if there is no formatter
    | refs: `#25792`_
  - **PR** `#25685`_: (*twangboy*) Fixed regex issues with comment and uncomment
  - **PR** `#25682`_: (*basepi*) [2015.5] Fix parsing args with just a hash (#)
  - **PR** `#25680`_: (*basepi*) [2015.5] Move cmd.run jinja aliasing to a wrapper class to prevent side effects
  - **PR** `#25677`_: (*aneeshusa*) Fix pacman.list_upgrades when refresh=True.
  - **PR** `#25676`_: (*basepi*) Update release candidate docs to 2015.8.0rc2
  - **PR** `#25675`_: (*UtahDave*) Use OS line endings with contents on file.managed
  - **PR** `#25671`_: (*niq000*) added a parameter so verifying SSL is now optional instead of hard-coded
    | refs: `#25738`_
  - **PR** `#25666`_: (*nmadhok*) Check if the properties exist before looping over them causing KeyError
  - **PR** `#25662`_: (*rallytime*) Back-port `#25638`_ to 2015.5
  - **PR** `#25661`_: (*rallytime*) Back-port `#25624`_ to 2015.5
  - **PR** `#25660`_: (*colekowalski*) add glusterfs' direct-io-mode to mount_invisible_keys
    | refs: `#25699`_ `#25709`_
  - **PR** `#25656`_: (*anlutro*) Fix locale detection in debian/gentoo
  - **PR** `#25648`_: (*twangboy*) Clarified functionality of reg module, fixed state to work with new module
  - **PR** `#25645`_: (*kev009*) Fix pkgng provider to work with a sources list and the underlying pkg…
  - **PR** `#25644`_: (*cachedout*) pillar doc fix
  - **PR** `#25642`_: (*cachedout*) Warn on pillar schedule delete
  - **PR** `#25638`_: (*TronPaul*) fix bad merge in 99fc7ec
    | refs: `#25662`_
  - **PR** `#25624`_: (*bobrik*) Fix typo in get_routes example for debian_ip
    | refs: `#25661`_
  - **PR** `#25608`_: (*rall0r*) Fix: prevent git.latest from removing target
    | refs: `#25737`_
  - **PR** `#25049`_: (*terminalmage*) Fix cmd.run when cross-called in a state/execution module
    | refs: `#25680`_
  * 7b50807 Merge pull request `#25902`_ from basepi/merge-forward-2015.8
  * 4d8ba6b Remove reg unit tests, not applicable to latest version of reg module

  * 876af79 Py3 compat

  * 579ba19 Fix lint

  * e29be76 Merge remote-tracking branch 'upstream/2015.5' into merge-forward-2015.8

    * af2326a Merge pull request `#25885`_ from t0rrant/patch-3

      * 3f73900 Update Debian changelog

    * 6ce0b3e Merge pull request `#25875`_ from rallytime/`bp-25862`_

      * d7f448d Needed popen.wait().

      * 25f8042 Checking for scp existance. Using command -v should be POSIX

      * 6b2100a New exitcode for SCP not found Re: https://github.com/saltstack/salt/issues/25478 and https://github.com/saltstack/salt/issues/25026

    * 66dcc55 Merge pull request `#25873`_ from rallytime/`bp-25855`_

      * f1f7ce2 Update saltmod.py

      * 23a6806 Update saltmod.py

    * bf8bd38 Merge pull request `#25871`_ from rallytime/`bp-25829`_

      * a80c47e Fixed typo in salt.states.saltmod.function doc string

    * f26310f Merge pull request `#25869`_ from rallytime/`bp-25788`_

      * 65b18e3 Catch a hard crash when running highstate on windows

    * 810fbb8 Merge pull request `#25853`_ from davidjb/ssh-id-wrapper-non-root

      * 6492bde Make ssh-id-wrapper accessible to non-root users

    * b6805b0 Merge pull request `#25856`_ from jfindlay/intro_scale

      * 5921461 style and usage consistency in intro_scale

      * 51dc7ca whitespace adjustments in intro_scale

      * 39a8246 expand minion reauth scalability documentation

    * 423d528 Merge pull request `#25840`_ from jfindlay/winrepo_master

      * b6cfd54 add note to winrepo state docs about required grain

    * 754c8be Merge pull request `#25846`_ from jfindlay/depr_code

      * d377f42 rework deprecation documentation for release names

    * d9ab4bb Merge pull request `#25833`_ from jahamn/fix-cp.push-not-recreating-empty-files

      * eac19fb Allows cp.push to recreate empty files

    * 6f93d64 Merge pull request `#25831`_ from rallytime/`fix-11474`_

      * 067ea78 Add salt:// to key_url options to docs for pkgrepo.managed

    * 72b3633 Merge pull request `#25807`_ from rallytime/`fix-22699`_

      * 3f3005c Use handle_exception function in cloud cli.py

      * f91edf3 Provide helpful error when using actions with a mapfile

    * 71497ad Merge pull request `#25818`_ from jfindlay/autoruns_users

      * c2dbb65 fix autoruns list for modern windowsen

    * 98b324c Merge pull request `#25826`_ from alprs/fix-onchanges_type_check

      * 7992a3f state.py: check that "onchanges" is a list

    * ad07dc1 Merge pull request `#25798`_ from twangboy/fix_25258

      * aa19c2b Fixed stacktrace on package name not found

    * 4a38d4a Merge pull request `#25797`_ from twangboy/fix_revert_in_25763

      * 81d5b5e Changed repocache back to cached_repo

    * 823f0ce Merge pull request `#25793`_ from rallytime/`bp-25730`_

      * 937779e patchelf lives in pkgsrc

    * 4109ae5 Merge pull request `#25792`_ from rallytime/`bp-25688`_

      * 0aa1416 Don't acquire lock if there is no formatter

    * 737fb14 Merge pull request `#25796`_ from cachedout/debug_doc

      * 33bfdf3 Remove debug from docs

    * a658753 Merge pull request `#25749`_ from jahamn/fix-zpool-special-char-device-support

      * 361f6cc Allow zpool.create on character devices

    * 1fae76d Merge pull request `#25685`_ from twangboy/fix_25594

      * a904e83 Fixed another test failure...

      * aa077d3 Fixed more tests... justin findlay helped me...

      * 87c8f8d Fixed some tests... maybe...

      * 3c1a73f Fixed some lint

      * b3e44e3 Fixed states to work with comment_line

      * b1cedd1 Fixed regex issues with comment and uncomment

    * 0bdb294 Merge pull request `#25763`_ from twangboy/fix_25437

      * 9e70c80 The real fix for 25437 that doesn't break other crap

      * d7347e0 Revert "Fixed problem trying to load file with name of boolean type"

      * cf57712 Merge branch '2015.5' of https://github.com/saltstack/salt into fix_25437

    * c123659 Merge pull request `#25752`_ from thatch45/state_top_saltenv

      * 65d6ec0 don't override the minion config unless requested

      * 26c8583 Add state_top_saltenv to the config chain

      * 36a3b67 Add raet support for state_top_saltnev

      * f6fa025 Add saltenv top file support to salt master_opts

      * 4a1c533 Add state_top_saltenv support

    * f367acb Merge pull request `#25755`_ from twangboy/fix_25717

      * 10e4105 Fixed problem with dunder functions not being passed

    * f05ae95 Merge pull request `#25648`_ from twangboy/fix_25352

      * d6496ce Merge pull request `#1`_ from jfindlay/reg

        * 3b0cc65 fix reg unit tests

      * b473fb7 Fixed some tests... maybe...

      * ff7296d Fixed some more lint

      * 7a71f5e Merge branch '2015.5' of https://github.com/saltstack/salt into fix_25352

      * f57b2b8 Fixed some line, added documentation

      * d78fa97 Merge branch '2015.5' of https://github.com/saltstack/salt into fix_25352

      * 99d9518 Clarified functionality of reg module, fixed state to work with new module

    * 29c66d8 Merge pull request `#25740`_ from rallytime/`bp-25722`_

      * c33eb81 Change docs for --static option with JSON - text B

      * 89dd2ec Change docs for --static option with JSON - text A

    * 135b03e Merge pull request `#25739`_ from rallytime/`bp-25709`_

      * fda2ffa add direct-io-mode to mount_invisible_options

    * 095a923 Merge pull request `#25738`_ from rallytime/`bp-25671`_

      * 525cd70 added a parameter so verifying SSL is now optional instead of hard-coded

    * 05fbfe6 Merge pull request `#25737`_ from rallytime/`bp-25608`_

      * df85d73 Fix: prevent git.latest from removing target Fixes `#25229`_ While force=True and test=True git.latest should not remove the target directory.

    * 9817fc5 Merge pull request `#25733`_ from davidjb/mount-fix

      * 6d0bce2 Test length of comps when listing mounts

    * 82ba390 Merge pull request `#25705`_ from blackduckx/augeas-setm

      * cad0f2b Augeas: fix pylint and documentation

      * ee97896 Support for setm augeas command.

    * f732be3 Merge pull request `#25703`_ from cachedout/master_type_2015_5

      * 0dc28ad Return to `str` for master_type for 2015.5

    * dea3d31 Merge pull request `#25702`_ from twangboy/fix_25144

      * d5be7a2 Fixed win_user moduele for groups with spaces in the name

    * 186af9b Merge pull request `#25711`_ from twangboy/fix_25351

      * 82fa911 Fixed problem with win_servermanager.list_installed

    * ad8456e Merge pull request `#25714`_ from cachedout/issue_25435

      * 44f3468 Included note in help docs

      * 4e2fee1 Display warning when progressbar can't be loaded

    * a0969ff Merge pull request `#25699`_ from rallytime/`bp-25660`_

      * 85c636d add glusterfs' direct-io-mode to mount_invisible_keys

    * fe82956 Merge pull request `#25694`_ from s0undt3ch/2015.5

      * afba3bd Use a relative un-nested path to the salt-call logfile.

      * 6309f22 Fix wrong variable assignment

      * c312592 Have cookie JAR's respect the configured `cachedir`

    * fb4744b Merge pull request `#25710`_ from jahamn/integration-test-for-issue-25250

      * 24f653e Integration Test for Issue 25250

    * 18c9d54 Merge pull request `#25680`_ from basepi/jinja.alias.25049

      * e83a0f9 Use new-style classes

      * 4a50bac Fix typo

      * 3641038 Name the Nitrogen release

      * 7767959 Make ALIASES global

      * 01c209e Fix some aliases references

      * 1644641 Move cmd.run aliasing to a wrapper class to prevent side effects

    * 6a5c6dc Merge pull request `#25682`_ from basepi/fix.hash.parsing

      * 8d75c1b Fix parsing args with just a hash (#)

    * d330ef0 Merge pull request `#25695`_ from stanislavb/expose-aws-region-config-and-fetch-region-from-metadata

      * 595da62 Configurable AWS region & region from IAM metadata

    * ea0d295 Merge pull request `#25645`_ from kev009/freebsd-pkgng-add

      * ee2cbb5 Fix pkgng provider to work with a sources list and the underlying pkg-add(8)

    * 2cad79c Merge pull request `#25677`_ from aneeshusa/fix-pacman-list-upgrades-when-refreshing

      * 7062ae4 Fix pacman.list_upgrades when refresh=True.

    * 18e739b Merge pull request `#25675`_ from UtahDave/2015.5local

      * d0f9d00 Use OS line endings with contents on file.managed

    * 7914f51 Merge pull request `#25676`_ from basepi/2015.8.0rc2releasedocs

      * 882d118 Update release candidate docs to 2015.8.0rc2

    * c36b714 Merge pull request `#25666`_ from nmadhok/vmware-cloud-fix_2015.5

      * 8e81229 Check if the properties exist before looping over them causing KeyErrors Fixes `#25665`_

    * 36d04b2 Merge pull request `#25656`_ from alprs/fix-locale_detection

      * a260236 change variable name

      * dd2a188 fix tests

      * aefd0fb code formatting

      * e58d222 fix locale detection in debian/gentoo

    * b1c1735 Merge pull request `#25661`_ from rallytime/`bp-25624`_

      * 4e1fcfa Fix typo in get_routes example for debian_ip

    * 6a2843d Merge pull request `#25662`_ from rallytime/`bp-25638`_

      * 90d833d fix bad merge 99fc7ec

    * 00f4689 Merge pull request `#25644`_ from cachedout/issue_25413

      * 8cef61e pillar doc fix

    * aeaeb53 Merge pull request `#25642`_ from cachedout/issue_25540

    * 74f6b69 Warn on pillar schedule delete

- **PR** `#25956`_: (*anlutro*) Fix user argument to cron functions
  @ *2015-08-03T19:40:16Z*

  - **ISSUE** `#23700`_: (*cachedout*) cron.present with user option is broken
    | refs: `#25956`_
  * 10813ca Merge pull request `#25956`_ from alprs/fix-cron_user
  * b3c1fa5 fix user argument to cron functions

- **PR** `#25946`_: (*sjorge*) Fix for salt.utils.decorators under esky
  @ *2015-08-03T19:39:32Z*

  - **ISSUE** `#25756`_: (*nshalman*) Esky builds on SmartOS broken in 2015.5 branch
    | refs: `#25946`_ `#25923`_
  - **PR** `#25923`_: (*sjorge*) Fix for salt.utils.decorators and module.__name__ under esky
    | refs: `#25946`_
  * aeb3b4e Merge pull request `#25946`_ from sjorge/esky-decorator-fix
  * bebdc26 inspect.getmodule fails without .py, using frame and f_global instead.

- **PR** `#25957`_: (*anlutro*) Remove temporary file after file.managed with checkcmd
  @ *2015-08-03T16:51:03Z*

  * 0bffcff Merge pull request `#25957`_ from alprs/fix-file_managed_checkcmd_remove
  * 60c250a file.managed: tmp_filename needs to always be defined

  * 0b10cea delete tmp file when file.managed has check_cmd arg

- **PR** `#25874`_: (*rallytime*) Back-port `#25668`_ to 2015.8
  @ *2015-08-03T16:40:42Z*

  - **PR** `#25668`_: (*techhat*) Sanitize sensitive fields in http.query()
    | refs: `#25874`_
  * 1ba7e8e Merge pull request `#25874`_ from rallytime/`bp-25668`_
  * a53d0e1 Pylint

  * 8e17d15 Trace log whether or not data is a dict

  * 026e5f9 Fix error introduced in `#25668`_

  * 745982f Sanitize sensitive fields in http.query()

- **PR** `#25929`_: (*sjorge*) salt.module.pkgin's __virtual__() should not return None if pkg_info is not present
  @ *2015-08-03T15:34:15Z*

  * 15b14b7 Merge pull request `#25929`_ from sjorge/fix-pkgin-module
  * 33e0f28 try to pass pylint, catch only the correct exception

  * 84e7583 pkgin module should not throw exception in _check_pkgin incase pkg_info is missing

- **PR** `#25952`_: (*garethgreenaway*) Log when event.fire and event.fire_master fail 2015.8
  @ *2015-08-03T00:20:19Z*

  * c636f7f Merge pull request `#25952`_ from garethgreenaway/2015_8_event_fire_failed_log_why
  * e4ac757 If we're unable to fire an event, log the cause so we know what happened

- **PR** `#25944`_: (*sjorge*) Smartos libcrypto nonesky fix
  @ *2015-08-01T18:14:43Z*

  - **ISSUE** `#2`_: (*thatch45*) salt job queries
  * cbd539f Merge pull request `#25944`_ from sjorge/smartos-libcrypto-nonesky-fix
  * 77239fa fix for loading libcrypto on non esky smartos

  * 59fcdf9 Merge pull request `#2`_ from saltstack/2015.8

- **PR** `#25906`_: (*dmurphy18*) Cherry-pick of pkgbuild changes from develop branch
  @ *2015-07-31T22:00:29Z*

  * 76d08d9 Merge pull request `#25906`_ from saltstack/dgm_pkgbuild
  * 897bab4 Fixes for pkgbuild, added support for dependencies building package

  * b6c0da3 Fixed pylint errors

  * aeacffd Added Debian execution module debbuild.py and rpmbuild.py fix

- **PR** `#25925`_: (*sjorge*) Create default log location in smartos esky buildscript
  @ *2015-07-31T20:21:05Z*

  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
  * 12d6aa3 Merge pull request `#25925`_ from sjorge/smartos-esky-fixes
  * ebb63f1 create log directory for smartos esky package

  * f4cdc70 Merge pull request `#1`_ from saltstack/2015.8

- **PR** `#25928`_: (*cachedout*) Fix stacktrace for non-existant states
  @ *2015-07-31T19:59:00Z*

  - **ISSUE** `#25813`_: (*whytewolf*) debconf.set throwing exception in 2015.8.0rc2
    | refs: `#25928`_
  * fe35490 Merge pull request `#25928`_ from cachedout/issue_25813
  * ce034e2 Fix stacktrace for non-existant states

- **PR** `#25922`_: (*jacksontj*) Correct max_wait -> max_auth_wait in MultiMinion
  @ *2015-07-31T17:17:55Z*

  - **ISSUE** `#25795`_: (*jtand*) Multimaster fails when using TCP transport mechanism
    | refs: `#25922`_
  * 2276d43 Merge pull request `#25922`_ from jacksontj/2015.8
  * 833950f Correct max_wait -> max_auth_wait in MultiMinion

- **PR** `#25907`_: (*rallytime*) Back-port `#25892`_ to 2015.8
  @ *2015-07-31T17:11:43Z*

  - **PR** `#25892`_: (*TheBigBear*) Update 7-zip msi un-installer instructions
    | refs: `#25905`_ `#25907`_
  * 6109806 Merge pull request `#25907`_ from rallytime/`bp-25892`_-dot-eight
  * 0d33bae Update 7-zip msi un-installer instructions

- **PR** `#25910`_: (*terminalmage*) Pass osarch to check_32()
  @ *2015-07-31T12:12:36Z*

  - **ISSUE** `#25776`_: (*tbaker57*) [2015.8.0rc2] pkg.installed performance regression
    | refs: `#25910`_
  * d30a99a Merge pull request `#25910`_ from terminalmage/issue25776
  * ae473ce Pass osarch to check_32()

- **PR** `#25849`_: (*basepi*) Repress template error for GPG renderer (can't seek an OrderedDict)
  @ *2015-07-30T23:25:06Z*

  - **ISSUE** `#25774`_: (*tbaker57*) [2015.8.0rc2] GPG renderer issue
    | refs: `#25849`_
  * cf6b179 Merge pull request `#25849`_ from basepi/gpg.renderer.25774
  * 9d7f7d5 Repress template error for GPG renderer (can't seek an OrderedDict)

- **PR** `#25868`_: (*rallytime*) Back-port `#25404`_ to 2015.8
  @ *2015-07-30T22:09:42Z*

  - **ISSUE** `#21082`_: (*clinta*) master_type failover does not failover on DNS errors
    | refs: `#25370`_ `#25404`_
  - **PR** `#25404`_: (*DmitryKuzmenko*) Fixed minion failover to next master on DNS errors.
    | refs: `#25868`_
  * 32019c5 Merge pull request `#25868`_ from rallytime/`bp-25404`_
  * e0f9a31 Fixed minion failover to next master on DNS errors.

- **PR** `#25896`_: (*cachedout*) Lint
  @ *2015-07-30T21:39:50Z*

  - **ISSUE** `#25720`_: (*jfindlay*) tcp transport: minion stack trace: Unhandled exception running mine.update
    | refs: `#25876`_
  - **PR** `#25876`_: (*jacksontj*) Fixes for 2015.8
    | refs: `#25896`_
  * c011511 Merge pull request `#25896`_ from cachedout/lint_25876
  * 1dc128b Lint

- **PR** `#25876`_: (*jacksontj*) Fixes for 2015.8
  | refs: `#25896`_
  @ *2015-07-30T21:38:12Z*

  - **ISSUE** `#25720`_: (*jfindlay*) tcp transport: minion stack trace: Unhandled exception running mine.update
    | refs: `#25876`_
  * 1b3ea19 Merge pull request `#25876`_ from jacksontj/2015.8
  * 088d73d Streams closing should not count as errors

  * ffb549e Print out debug line with pre-msgpacked message

  * f414eb4 Start the minion event publisher before attempting to connect to a master.

  * fe62ce5 Handle errors sending mine datas to master

- **PR** `#25867`_: (*rallytime*) Back-port `#25370`_ to 2015.8
  @ *2015-07-30T17:33:28Z*

  - **ISSUE** `#21082`_: (*clinta*) master_type failover does not failover on DNS errors
    | refs: `#25370`_ `#25404`_
  - **PR** `#25370`_: (*DmitryKuzmenko*) Fix: minion doesn't set tok property in masters list case.
    | refs: `#25867`_
  * c24970e Merge pull request `#25867`_ from rallytime/`bp-25370`_
  * c51d8c4 Fix: minion doesn't set tok property in masters list case.

- **PR** `#25845`_: (*jacobhammons*) updated versionadded
  @ *2015-07-30T16:50:26Z*

  - **ISSUE** `#24813`_: (*iggy*) salt.runner.manage versionadded annotations are wrong
    | refs: `#25845`_
  * e1ac2a3 Merge pull request `#25845`_ from jacobhammons/24813
  * 7019fa4 updated versionadded Refs `#24813`_

- **PR** `#25836`_: (*jacksontj*) Keep track of SyncWrapper's IOLoop usage
  @ *2015-07-30T14:37:50Z*

  - **ISSUE** `#25718`_: (*jfindlay*) tcp transport stacktrace on windows minion: Future exception was never retrieved
    | refs: `#25836`_
  * c5bb5bc Merge pull request `#25836`_ from jacksontj/2015.8
  * 9ab57fd Switch to WeakKeyDictionary to support python 2.6

  * fb4cdc4 Keep track of SyncWrapper's IOLoop usage

- **PR** `#25859`_: (*0xf10e*) warn_until(Carbon,...) instead of Boron
  @ *2015-07-30T14:15:38Z*

  - **ISSUE** `#25814`_: (*whytewolf*) glance.image_create no longer working with copy_from and is_public in 2015.8.0rc2
    | refs: `#25859`_
  * 5b236a2 Merge pull request `#25859`_ from 0xf10e/fix_glance_warn_until
  * d4db6d1 warn_until(Carbon,...) instead of Boron

- **PR** `#25505`_: (*0xf10e*) Glance state module for 2015.8 "Beryllium"
  @ *2015-07-29T20:55:56Z*

  - **ISSUE** `#25814`_: (*whytewolf*) glance.image_create no longer working with copy_from and is_public in 2015.8.0rc2
    | refs: `#25859`_
  * f06dd05 Merge pull request `#25505`_ from 0xf10e/glance_state_module_boron
  * e87f35d return error when finding multiple images in glance.image_update

  * f050db5 add default for 'visibility', should fix `#25814`_

  * 2991e40 restore the image_create interface from 2015.5.3

  * fa0b784 correct release names

  * f555b09 fix imports

  * 9714a63 add warn_until('Carbon',...) where code will be obsolete

  * 84953c6 Change behavior in Carbon, but no RuntimeError until Nitrogen

  * 1665785 PEP8 E261/PEP8 E302/PEP8 E502/E1305

  * 4509ad0 more clean-up, get version info from salt.version

  * 3f35d4a keep args in same order as they were before

  * 8859579 fix E8211/C0326

  * ec0d17d fix W1699(incompatible-py3-code)

  * 04f8980 fix returning changed visibility

  * ddd06c4 up until Boron wrap result in a dict

  * f4249e7 return changes on visibility

  * a0dad3b image_present: if len(acceptable) drops to 0 we've got a problem...

  * 763189c cherry-picking some clean-up

  * fa219d3 import of prototype of image_update() from lithium branch glance_state_module

  * 2e7b154 Catch HTTPForbidden and return an Error

  * 73ba331 Refresh image details if active but w/o checksum

  * a6d7d3f Add missing parameter "protected" to image_create

  * 0b89931 image_list:check saltversion to determine behavior

  * e54ef56 build ret{} with matching images

  * 5350baa Catch HTTPNotFound and return error

  * 95db1d6 added option "test" - not yet well tested :D

  * 076f20c Add optional parameter "name"

  * 4717341 LINTing...

  * e6f63cd fix loop over acceptable states and comment not verifying the ckecksum if wait_for < active

  * fbdd548 glance.image_present almost working

  * 5343bf1 created own function _find_image() to resolve image names

  * 0275615 also comment correct values

  * 82b5e5e add param checksum to image_present()

  * 6325f58 very basic glance.image_present

- **PR** `#25843`_: (*jtand*) Fixed a lint error in parsers.py
  @ *2015-07-29T19:49:41Z*

  * 2d12fc4 Merge pull request `#25843`_ from jtand/parser_lint
  * 47f5aa2 Fixed a lint error in parsers.py

- **PR** `#25835`_: (*techhat*) spm update_repo doesn't always require arguments
  @ *2015-07-29T19:48:24Z*

  * 2510b8b Merge pull request `#25835`_ from techhat/spmupdaterepo
  * 4fae852 Need a comma

- **PR** `#25837`_: (*jacobhammons*) regenerated man pages
  @ *2015-07-29T17:39:40Z*

  * 2c3a97f Merge pull request `#25837`_ from jacobhammons/man-page-updates
  * 0e02191 regenerated man pages

- **PR** `#25830`_: (*sjorge*) Loading of libcrypto on smartos esky fixed
  @ *2015-07-29T17:39:12Z*

  - **ISSUE** `#25757`_: (*sjorge*) Esky builds on SmartOS broken in 2015.8 branch, by find_library
    | refs: `#25820`_ `#25830`_
  * d6a26a0 Merge pull request `#25830`_ from sjorge/smartos-libcrypto-fix
  * 9b8091e fix also needed for esky package inside a zone

  * 65fa7ca Merge branch 'smartos-libcrypto-prereq' into smartos-libcrypto-fix

  * c95f7ac fix loading of libcrypto in smartos eksy package

* 733b842 spm update_repo doesn't always require arguments


- **PR** `#25808`_: (*jfindlay*) add highstate opts to config/__init__.py, update docs
  @ *2015-07-29T15:30:05Z*

  * db7cf2d Merge pull request `#25808`_ from jfindlay/doc_conf
  * cd9a485 document state_output_diff and sudo_user configs

  * d73964e add console_log_fmt color documentation

- **PR** `#25820`_: (*sjorge*) Prerequisite to fix the smartos libcrypto loading
  @ *2015-07-29T14:26:22Z*

  - **ISSUE** `#25757`_: (*sjorge*) Esky builds on SmartOS broken in 2015.8 branch, by find_library
    | refs: `#25820`_ `#25830`_
  * a7c3dc5 Merge pull request `#25820`_ from sjorge/smartos-libcrypto-prereq
  * be95ec4 fix indentation

  * f001d7e minor style correction

  * 62c0441 implement is_smartos_globalzone() - complex check to see if we are smartos and running in the global zone

  * 9edde56 add salt.util.is_smartos - check if is_sunos() + joyent_ in uname

- **PR** `#25781`_: (*anlutro*) Fix iptables.build_rule
  @ *2015-07-28T22:55:19Z*

  * 704033f Merge pull request `#25781`_ from alprs/fix-iptables_build_rule
  * 4ce0606 iptables.build_rule - rule is a list, not a string

- **PR** `#25764`_: (*gtmanfred*) allow use of cloudnetworks in ssh_interface
  @ *2015-07-28T02:40:06Z*

  - **ISSUE** `#24855`_: (*gtmanfred*) salt-cloud nova driver doesn't work with private ips
    | refs: `#25764`_
  * 13c2377 Merge pull request `#25764`_ from gtmanfred/2015.8
  * 53ce470 make sure to set access_ip

  * 9890041 fix appostrophe

  * 5185939 add a note in the documentation for openstack

  * a1b3d41 add ability to specify a cloudnetwork in ssh_interfaces

- **PR** `#25736`_: (*jfindlay*) insert explicit formatter number
  @ *2015-07-27T17:46:34Z*

  - **ISSUE** `#25732`_: (*tbaker57*) [2015.8.0rc2] String formatting fails on Centos 6 - python 2.7 dependency?
    | refs: `#25736`_
  * 5b24f6a Merge pull request `#25736`_ from jfindlay/format
  * 7bb93fe insert explicit formatter number

- **PR** `#25742`_: (*rallytime*) Back-port `#25731`_ to 2015.8
  @ *2015-07-27T17:42:14Z*

  - **PR** `#25731`_: (*sjorge*) cleanup of python requirements
    | refs: `#25742`_
  * e74fdea Merge pull request `#25742`_ from rallytime/`bp-25731`_
  * c825683 cleanup of python requirements

- **PR** `#25741`_: (*rallytime*) Back-port `#25727`_ to 2015.8
  @ *2015-07-27T17:41:53Z*

  - **ISSUE** `#25726`_: (*dougluce*) pkg add -y ... failed with return code: 64
    | refs: `#25727`_
  - **PR** `#25727`_: (*dougluce*) Fix pkg.installed using salt:// sources on FreeBSD
    | refs: `#25741`_
  * 4f41e91 Merge pull request `#25741`_ from rallytime/`bp-25727`_
  * c4c356d Fix pkg.installed using salt:// sources on FreeBSD

- **PR** `#25712`_: (*cachedout*) Fix outputter for state.apply
  @ *2015-07-24T22:13:10Z*

  - **ISSUE** `#25486`_: (*whiteinge*) Highstate outputter not used for state.apply
    | refs: `#25712`_
  * dca09f8 Merge pull request `#25712`_ from cachedout/issue_25486
  * fa211e8 Fix outputter for state.apply

- **PR** `#25698`_: (*rallytime*) Back-port `#25659`_ to 2015.8
  | refs: `#25890`_
  @ *2015-07-24T22:11:23Z*

  - **PR** `#25659`_: (*isbm*) Bugfix: crash at getting non-existing repo
    | refs: `#25698`_
  * d43abb4 Merge pull request `#25698`_ from rallytime/`bp-25659`_
  * a611c86 Bugfix: crash at getting non-existing repo

- **PR** `#25690`_: (*anlutro*) Fix highstate duration alignment (again)
  @ *2015-07-24T15:58:08Z*

  * b114f37 Merge pull request `#25690`_ from alprs/fix-highstate_duration_line_length-2
  * 4121152 fix highstate duration alignment

- **PR** `#25684`_: (*davidjb*) Fix doc around Include/Exclude for states
  @ *2015-07-23T23:53:44Z*

  - **ISSUE** `#1`_: (*thatch45*) Enable regex on the salt cli
  * 37766e9 Merge pull request `#25684`_ from davidjb/doc-`fix-1`_
  * f653970 Fix doc around Include/Exclude for states

- **PR** `#25549`_: (*techhat*) Switch Scaleway to salt.utils.cloud.bootstrap()
  @ **

  * a4aaa7a Merge pull request `#25549`_ from techhat/scalewaybootstrap
  * f645d05 More linting

  * bc22ff1 Linting

  * 609bc45 Switch Scaleway to salt.utils.cloud.bootstrap()


.. _`#1`: https://github.com/saltstack/salt/issues/1
.. _`#11474`: https://github.com/saltstack/salt/issues/11474
.. _`#14690`: https://github.com/saltstack/salt/pull/14690
.. _`#15209`: https://github.com/saltstack/salt/issues/15209
.. _`#19532`: https://github.com/saltstack/salt/issues/19532
.. _`#2`: https://github.com/saltstack/salt/issues/2
.. _`#21082`: https://github.com/saltstack/salt/issues/21082
.. _`#21296`: https://github.com/saltstack/salt/issues/21296
.. _`#22460`: https://github.com/saltstack/salt/issues/22460
.. _`#22699`: https://github.com/saltstack/salt/issues/22699
.. _`#23288`: https://github.com/saltstack/salt/issues/23288
.. _`#23700`: https://github.com/saltstack/salt/issues/23700
.. _`#23764`: https://github.com/saltstack/salt/issues/23764
.. _`#23788`: https://github.com/saltstack/salt/issues/23788
.. _`#24002`: https://github.com/saltstack/salt/issues/24002
.. _`#24036`: https://github.com/saltstack/salt/issues/24036
.. _`#24042`: https://github.com/saltstack/salt/issues/24042
.. _`#24813`: https://github.com/saltstack/salt/issues/24813
.. _`#24855`: https://github.com/saltstack/salt/issues/24855
.. _`#24920`: https://github.com/saltstack/salt/issues/24920
.. _`#25026`: https://github.com/saltstack/salt/issues/25026
.. _`#25049`: https://github.com/saltstack/salt/pull/25049
.. _`#25144`: https://github.com/saltstack/salt/issues/25144
.. _`#25153`: https://github.com/saltstack/salt/issues/25153
.. _`#25154`: https://github.com/saltstack/salt/issues/25154
.. _`#25229`: https://github.com/saltstack/salt/issues/25229
.. _`#25250`: https://github.com/saltstack/salt/issues/25250
.. _`#25258`: https://github.com/saltstack/salt/issues/25258
.. _`#25351`: https://github.com/saltstack/salt/issues/25351
.. _`#25352`: https://github.com/saltstack/salt/issues/25352
.. _`#25370`: https://github.com/saltstack/salt/pull/25370
.. _`#25404`: https://github.com/saltstack/salt/pull/25404
.. _`#25413`: https://github.com/saltstack/salt/issues/25413
.. _`#25435`: https://github.com/saltstack/salt/issues/25435
.. _`#25437`: https://github.com/saltstack/salt/issues/25437
.. _`#25447`: https://github.com/saltstack/salt/issues/25447
.. _`#25478`: https://github.com/saltstack/salt/issues/25478
.. _`#25486`: https://github.com/saltstack/salt/issues/25486
.. _`#25505`: https://github.com/saltstack/salt/pull/25505
.. _`#25540`: https://github.com/saltstack/salt/issues/25540
.. _`#25549`: https://github.com/saltstack/salt/pull/25549
.. _`#25557`: https://github.com/saltstack/salt/issues/25557
.. _`#25577`: https://github.com/saltstack/salt/issues/25577
.. _`#25608`: https://github.com/saltstack/salt/pull/25608
.. _`#25624`: https://github.com/saltstack/salt/pull/25624
.. _`#25633`: https://github.com/saltstack/salt/pull/25633
.. _`#25638`: https://github.com/saltstack/salt/pull/25638
.. _`#25642`: https://github.com/saltstack/salt/pull/25642
.. _`#25644`: https://github.com/saltstack/salt/pull/25644
.. _`#25645`: https://github.com/saltstack/salt/pull/25645
.. _`#25648`: https://github.com/saltstack/salt/pull/25648
.. _`#25650`: https://github.com/saltstack/salt/issues/25650
.. _`#25656`: https://github.com/saltstack/salt/pull/25656
.. _`#25657`: https://github.com/saltstack/salt/pull/25657
.. _`#25659`: https://github.com/saltstack/salt/pull/25659
.. _`#25660`: https://github.com/saltstack/salt/pull/25660
.. _`#25661`: https://github.com/saltstack/salt/pull/25661
.. _`#25662`: https://github.com/saltstack/salt/pull/25662
.. _`#25665`: https://github.com/saltstack/salt/issues/25665
.. _`#25666`: https://github.com/saltstack/salt/pull/25666
.. _`#25668`: https://github.com/saltstack/salt/pull/25668
.. _`#25671`: https://github.com/saltstack/salt/pull/25671
.. _`#25674`: https://github.com/saltstack/salt/issues/25674
.. _`#25675`: https://github.com/saltstack/salt/pull/25675
.. _`#25676`: https://github.com/saltstack/salt/pull/25676
.. _`#25677`: https://github.com/saltstack/salt/pull/25677
.. _`#25680`: https://github.com/saltstack/salt/pull/25680
.. _`#25682`: https://github.com/saltstack/salt/pull/25682
.. _`#25684`: https://github.com/saltstack/salt/pull/25684
.. _`#25685`: https://github.com/saltstack/salt/pull/25685
.. _`#25688`: https://github.com/saltstack/salt/pull/25688
.. _`#25689`: https://github.com/saltstack/salt/issues/25689
.. _`#25690`: https://github.com/saltstack/salt/pull/25690
.. _`#25694`: https://github.com/saltstack/salt/pull/25694
.. _`#25695`: https://github.com/saltstack/salt/pull/25695
.. _`#25696`: https://github.com/saltstack/salt/pull/25696
.. _`#25698`: https://github.com/saltstack/salt/pull/25698
.. _`#25699`: https://github.com/saltstack/salt/pull/25699
.. _`#25701`: https://github.com/saltstack/salt/issues/25701
.. _`#25702`: https://github.com/saltstack/salt/pull/25702
.. _`#25703`: https://github.com/saltstack/salt/pull/25703
.. _`#25704`: https://github.com/saltstack/salt/pull/25704
.. _`#25705`: https://github.com/saltstack/salt/pull/25705
.. _`#25709`: https://github.com/saltstack/salt/pull/25709
.. _`#25710`: https://github.com/saltstack/salt/pull/25710
.. _`#25711`: https://github.com/saltstack/salt/pull/25711
.. _`#25712`: https://github.com/saltstack/salt/pull/25712
.. _`#25714`: https://github.com/saltstack/salt/pull/25714
.. _`#25717`: https://github.com/saltstack/salt/issues/25717
.. _`#25718`: https://github.com/saltstack/salt/issues/25718
.. _`#25720`: https://github.com/saltstack/salt/issues/25720
.. _`#25722`: https://github.com/saltstack/salt/pull/25722
.. _`#25726`: https://github.com/saltstack/salt/issues/25726
.. _`#25727`: https://github.com/saltstack/salt/pull/25727
.. _`#25730`: https://github.com/saltstack/salt/pull/25730
.. _`#25731`: https://github.com/saltstack/salt/pull/25731
.. _`#25732`: https://github.com/saltstack/salt/issues/25732
.. _`#25733`: https://github.com/saltstack/salt/pull/25733
.. _`#25736`: https://github.com/saltstack/salt/pull/25736
.. _`#25737`: https://github.com/saltstack/salt/pull/25737
.. _`#25738`: https://github.com/saltstack/salt/pull/25738
.. _`#25739`: https://github.com/saltstack/salt/pull/25739
.. _`#25740`: https://github.com/saltstack/salt/pull/25740
.. _`#25741`: https://github.com/saltstack/salt/pull/25741
.. _`#25742`: https://github.com/saltstack/salt/pull/25742
.. _`#25749`: https://github.com/saltstack/salt/pull/25749
.. _`#25750`: https://github.com/saltstack/salt/pull/25750
.. _`#25752`: https://github.com/saltstack/salt/pull/25752
.. _`#25755`: https://github.com/saltstack/salt/pull/25755
.. _`#25756`: https://github.com/saltstack/salt/issues/25756
.. _`#25757`: https://github.com/saltstack/salt/issues/25757
.. _`#25763`: https://github.com/saltstack/salt/pull/25763
.. _`#25764`: https://github.com/saltstack/salt/pull/25764
.. _`#25774`: https://github.com/saltstack/salt/issues/25774
.. _`#25776`: https://github.com/saltstack/salt/issues/25776
.. _`#25781`: https://github.com/saltstack/salt/pull/25781
.. _`#25788`: https://github.com/saltstack/salt/pull/25788
.. _`#25792`: https://github.com/saltstack/salt/pull/25792
.. _`#25793`: https://github.com/saltstack/salt/pull/25793
.. _`#25795`: https://github.com/saltstack/salt/issues/25795
.. _`#25796`: https://github.com/saltstack/salt/pull/25796
.. _`#25797`: https://github.com/saltstack/salt/pull/25797
.. _`#25798`: https://github.com/saltstack/salt/pull/25798
.. _`#25801`: https://github.com/saltstack/salt/issues/25801
.. _`#25807`: https://github.com/saltstack/salt/pull/25807
.. _`#25808`: https://github.com/saltstack/salt/pull/25808
.. _`#25810`: https://github.com/saltstack/salt/issues/25810
.. _`#25813`: https://github.com/saltstack/salt/issues/25813
.. _`#25814`: https://github.com/saltstack/salt/issues/25814
.. _`#25818`: https://github.com/saltstack/salt/pull/25818
.. _`#25820`: https://github.com/saltstack/salt/pull/25820
.. _`#25824`: https://github.com/saltstack/salt/pull/25824
.. _`#25826`: https://github.com/saltstack/salt/pull/25826
.. _`#25827`: https://github.com/saltstack/salt/issues/25827
.. _`#25829`: https://github.com/saltstack/salt/pull/25829
.. _`#25830`: https://github.com/saltstack/salt/pull/25830
.. _`#25831`: https://github.com/saltstack/salt/pull/25831
.. _`#25832`: https://github.com/saltstack/salt/pull/25832
.. _`#25833`: https://github.com/saltstack/salt/pull/25833
.. _`#25835`: https://github.com/saltstack/salt/pull/25835
.. _`#25836`: https://github.com/saltstack/salt/pull/25836
.. _`#25837`: https://github.com/saltstack/salt/pull/25837
.. _`#25838`: https://github.com/saltstack/salt/issues/25838
.. _`#25839`: https://github.com/saltstack/salt/issues/25839
.. _`#25840`: https://github.com/saltstack/salt/pull/25840
.. _`#25843`: https://github.com/saltstack/salt/pull/25843
.. _`#25845`: https://github.com/saltstack/salt/pull/25845
.. _`#25846`: https://github.com/saltstack/salt/pull/25846
.. _`#25848`: https://github.com/saltstack/salt/pull/25848
.. _`#25849`: https://github.com/saltstack/salt/pull/25849
.. _`#25850`: https://github.com/saltstack/salt/issues/25850
.. _`#25852`: https://github.com/saltstack/salt/issues/25852
.. _`#25853`: https://github.com/saltstack/salt/pull/25853
.. _`#25855`: https://github.com/saltstack/salt/pull/25855
.. _`#25856`: https://github.com/saltstack/salt/pull/25856
.. _`#25859`: https://github.com/saltstack/salt/pull/25859
.. _`#25862`: https://github.com/saltstack/salt/pull/25862
.. _`#25863`: https://github.com/saltstack/salt/issues/25863
.. _`#25864`: https://github.com/saltstack/salt/pull/25864
.. _`#25867`: https://github.com/saltstack/salt/pull/25867
.. _`#25868`: https://github.com/saltstack/salt/pull/25868
.. _`#25869`: https://github.com/saltstack/salt/pull/25869
.. _`#25870`: https://github.com/saltstack/salt/pull/25870
.. _`#25871`: https://github.com/saltstack/salt/pull/25871
.. _`#25873`: https://github.com/saltstack/salt/pull/25873
.. _`#25874`: https://github.com/saltstack/salt/pull/25874
.. _`#25875`: https://github.com/saltstack/salt/pull/25875
.. _`#25876`: https://github.com/saltstack/salt/pull/25876
.. _`#25877`: https://github.com/saltstack/salt/pull/25877
.. _`#25885`: https://github.com/saltstack/salt/pull/25885
.. _`#25890`: https://github.com/saltstack/salt/pull/25890
.. _`#25892`: https://github.com/saltstack/salt/pull/25892
.. _`#25894`: https://github.com/saltstack/salt/pull/25894
.. _`#25895`: https://github.com/saltstack/salt/pull/25895
.. _`#25896`: https://github.com/saltstack/salt/pull/25896
.. _`#25898`: https://github.com/saltstack/salt/pull/25898
.. _`#25899`: https://github.com/saltstack/salt/issues/25899
.. _`#25902`: https://github.com/saltstack/salt/pull/25902
.. _`#25905`: https://github.com/saltstack/salt/pull/25905
.. _`#25906`: https://github.com/saltstack/salt/pull/25906
.. _`#25907`: https://github.com/saltstack/salt/pull/25907
.. _`#25910`: https://github.com/saltstack/salt/pull/25910
.. _`#25917`: https://github.com/saltstack/salt/pull/25917
.. _`#25919`: https://github.com/saltstack/salt/pull/25919
.. _`#25921`: https://github.com/saltstack/salt/pull/25921
.. _`#25922`: https://github.com/saltstack/salt/pull/25922
.. _`#25923`: https://github.com/saltstack/salt/pull/25923
.. _`#25925`: https://github.com/saltstack/salt/pull/25925
.. _`#25927`: https://github.com/saltstack/salt/pull/25927
.. _`#25928`: https://github.com/saltstack/salt/pull/25928
.. _`#25929`: https://github.com/saltstack/salt/pull/25929
.. _`#25938`: https://github.com/saltstack/salt/pull/25938
.. _`#25941`: https://github.com/saltstack/salt/pull/25941
.. _`#25942`: https://github.com/saltstack/salt/pull/25942
.. _`#25944`: https://github.com/saltstack/salt/pull/25944
.. _`#25946`: https://github.com/saltstack/salt/pull/25946
.. _`#25951`: https://github.com/saltstack/salt/pull/25951
.. _`#25952`: https://github.com/saltstack/salt/pull/25952
.. _`#25956`: https://github.com/saltstack/salt/pull/25956
.. _`#25957`: https://github.com/saltstack/salt/pull/25957
.. _`#25966`: https://github.com/saltstack/salt/pull/25966
.. _`#25967`: https://github.com/saltstack/salt/pull/25967
.. _`#25978`: https://github.com/saltstack/salt/pull/25978
.. _`#25979`: https://github.com/saltstack/salt/pull/25979
.. _`#25982`: https://github.com/saltstack/salt/pull/25982
.. _`#25988`: https://github.com/saltstack/salt/pull/25988
.. _`#25989`: https://github.com/saltstack/salt/pull/25989
.. _`#25997`: https://github.com/saltstack/salt/pull/25997
.. _`#25999`: https://github.com/saltstack/salt/pull/25999
.. _`#26001`: https://github.com/saltstack/salt/pull/26001
.. _`bp-25370`: https://github.com/saltstack/salt/pull/25370
.. _`bp-25404`: https://github.com/saltstack/salt/pull/25404
.. _`bp-25608`: https://github.com/saltstack/salt/pull/25608
.. _`bp-25624`: https://github.com/saltstack/salt/pull/25624
.. _`bp-25638`: https://github.com/saltstack/salt/pull/25638
.. _`bp-25659`: https://github.com/saltstack/salt/pull/25659
.. _`bp-25660`: https://github.com/saltstack/salt/pull/25660
.. _`bp-25668`: https://github.com/saltstack/salt/pull/25668
.. _`bp-25671`: https://github.com/saltstack/salt/pull/25671
.. _`bp-25688`: https://github.com/saltstack/salt/pull/25688
.. _`bp-25696`: https://github.com/saltstack/salt/pull/25696
.. _`bp-25709`: https://github.com/saltstack/salt/pull/25709
.. _`bp-25722`: https://github.com/saltstack/salt/pull/25722
.. _`bp-25727`: https://github.com/saltstack/salt/pull/25727
.. _`bp-25730`: https://github.com/saltstack/salt/pull/25730
.. _`bp-25731`: https://github.com/saltstack/salt/pull/25731
.. _`bp-25788`: https://github.com/saltstack/salt/pull/25788
.. _`bp-25824`: https://github.com/saltstack/salt/pull/25824
.. _`bp-25829`: https://github.com/saltstack/salt/pull/25829
.. _`bp-25832`: https://github.com/saltstack/salt/pull/25832
.. _`bp-25855`: https://github.com/saltstack/salt/pull/25855
.. _`bp-25862`: https://github.com/saltstack/salt/pull/25862
.. _`bp-25864`: https://github.com/saltstack/salt/pull/25864
.. _`bp-25892`: https://github.com/saltstack/salt/pull/25892
.. _`bp-25917`: https://github.com/saltstack/salt/pull/25917
.. _`fix-1`: https://github.com/saltstack/salt/issues/1
.. _`fix-11474`: https://github.com/saltstack/salt/issues/11474
.. _`fix-22699`: https://github.com/saltstack/salt/issues/22699
.. _`fix-24036`: https://github.com/saltstack/salt/issues/24036
